esparto
=======

[![image](https://img.shields.io/pypi/v/esparto.svg)](https://pypi.python.org/pypi/esparto)
[![Build Status](https://travis-ci.com/domvwt/esparto.svg?branch=main)](https://travis-ci.com/domvwt/esparto)
[![codecov](https://codecov.io/gh/domvwt/esparto/branch/main/graph/badge.svg?token=35J8NZCUYC)](https://codecov.io/gh/domvwt/esparto)
[![Quality Gate Status](https://sonarcloud.io/api/project_badges/measure?project=domvwt_esparto&metric=alert_status)](https://sonarcloud.io/dashboard?id=domvwt_esparto)

Esparto is a super minimal frontend web framework written in Python. Its primary use is for generating shareable single page documents
with content from popular analytics and data science libraries.

Full documentation and examples at [domvwt.github.io/esparto/](https://domvwt.github.io/esparto/).

### Features
* Lightweight API
* No CSS or HTML required
* Device responsive display
* Self contained / inline dependencies
* Jupyter Notebook support
* MIT License

## Supported Content
* Markdown text
* Images
* Matplotlib figures
* Pandas DataFrames
* Bokeh objects
* Plotly figures
